@@ -1,7 +1,6 @@
 """Host-name detection class"""
 
 import platform
-
 from typing import Optional
 
 from archey.entry import Entry
@@ -9,6 +8,7 @@ from archey.entry import Entry
 
 class Hostname(Entry):
     """Read system file with fallback on `platform` module to retrieve the system host-name"""
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
@@ -19,7 +19,7 @@ class Hostname(Entry):
     @staticmethod
     def _read_etc_hostname() -> Optional[str]:
         try:
-            with open('/etc/hostname', encoding='UTF-8') as f_hostname:
+            with open("/etc/hostname", encoding="UTF-8") as f_hostname:
                 return f_hostname.read().rstrip()
         except FileNotFoundError:
             return None
