@@ -2,7 +2,6 @@
 
 from archey.colors import Colors
 
-
 COLORS = [Colors.BLUE_BRIGHT, Colors.BLUE_NORMAL, Colors.WHITE_BRIGHT]
 
 # pylint: disable=line-too-long
@@ -24,5 +23,5 @@ LOGO = [
     """{c[0]} {c[1]}::::{c[2]}dMMNdyydNMMNo{c[1]}::::::::::::'{c[0]}    """,
     """{c[0]} {c[1]}:::::{c[2]}sdNMMMMNds{c[1]}::::::::::::'{c[0]}      """,
     """{c[0]} {c[1]}::::::::{c[2]}'YY'{c[1]}::::::::::::'{c[0]}         """,
-    """{c[0]} {c[1]}\\:::::::::::::::::'''{c[0]}             """
+    """{c[0]} {c[1]}\\:::::::::::::::::'''{c[0]}             """,
 ]
