@@ -2,7 +2,6 @@
 
 from archey.colors import Colors
 
-
 COLORS = [Colors.BLUE_NORMAL, Colors.CYAN_NORMAL]
 
 LOGO = [
@@ -24,5 +23,5 @@ LOGO = [
     """{c[0]}             .:::::::: {c[1]}'::::::::::{c[0]}          """,
     """{c[0]}            .::::''::::.     {c[1]}'::::.{c[0]}         """,
     """{c[0]}           .::::'   ::::.     {c[1]}'::::.{c[0]}        """,
-    """{c[0]}          .::::      ::::      {c[1]}'::::.{c[0]}       """
+    """{c[0]}          .::::      ::::      {c[1]}'::::.{c[0]}       """,
 ]
