@@ -2,7 +2,6 @@
 
 from archey.colors import Colors
 
-
 COLORS = [Colors.GREEN_BRIGHT]
 
 LOGO = [
@@ -17,12 +16,12 @@ LOGO = [
     """{c[0]} iiiliiiiliiiiiiili>`      ~liililii""",
     """{c[0]} liliiiliiilililii`         -9liiiil""",
     """{c[0]} iiiiiliiliiiiii~             "4lili""",
-    """{c[0]} 4ililiiiiilil~|      -w,       )4lf""",
+    """{c[0]} 4ililiiiiilil~       -w,       )4lf""",
     """{c[0]} -liiiiililiF'       _liig,       )'""",
     """{c[0]}  )iiiliii@`       _QIililig,       """,
     """{c[0]}   )iiii>`       .Qliliiiililw      """,
     """{c[0]}    )<>~       .mliiiiiliiiiiil,    """,
     """{c[0]}             _gllilililiililii~     """,
     """{c[0]}            giliiiiiiiiiiiiT`       """,
-    """{c[0]}           -^~$ililili@~~'          """
+    """{c[0]}           -^~$ililili@~~'          """,
 ]
