@@ -2,25 +2,24 @@
 
 import os
 import tempfile
-
-from subprocess import CalledProcessError
-
 import unittest
+from subprocess import CalledProcessError
 from unittest.mock import MagicMock, Mock, patch
 
 from archey.configuration import DEFAULT_CONFIG
 from archey.entries.temperature import Temperature
-from archey.test.entries import HelperMethods
 from archey.test import CustomAssertions
+from archey.test.entries import HelperMethods
 
 
 class TestTemperatureEntry(unittest.TestCase, CustomAssertions):
     """This module verifies Archey temperature detection"""
+
     def setUp(self):
         self.temperature_mock = HelperMethods.entry_mock(Temperature)
         self.temperature_mock._temps = []  # pylint: disable=protected-access
 
-    @patch('archey.entries.temperature.run')  # Mock the `sensors` call.
+    @patch("archey.entries.temperature.run")  # Mock the `sensors` call.
     def test_run_sensors_ok(self, run_mock):
         """Test computations around `sensors` output"""
         run_mock.return_value.stdout = """\
@@ -81,12 +80,11 @@ class TestTemperatureEntry(unittest.TestCase, CustomAssertions):
         # pylint: disable=protected-access
         Temperature._run_sensors(self.temperature_mock)
         self.assertListEqual(
-            self.temperature_mock._temps,
-            [45.0, 38.0, 39.0, 114.0, 45.0, 43.0, 44.0]
+            self.temperature_mock._temps, [45.0, 38.0, 39.0, 114.0, 45.0, 43.0, 44.0]
         )
         # pylint: enable=protected-access
 
-    @patch('archey.entries.temperature.run')
+    @patch("archey.entries.temperature.run")
     def test_run_sensors_ok_multiple_chipsets(self, run_mock):
         """Test `sensors` when multiple chipsets names have been passed"""
         run_mock.side_effect = [
@@ -109,7 +107,7 @@ class TestTemperatureEntry(unittest.TestCase, CustomAssertions):
    }
 }
 """,
-                stderr=None
+                stderr=None,
             ),
             Mock(
                 stdout="""\
@@ -124,11 +122,11 @@ class TestTemperatureEntry(unittest.TestCase, CustomAssertions):
     }
 }
 """,
-                stderr=None
-            )
+                stderr=None,
+            ),
         ]
 
-        sensors_chipsets = ['who-cares-about', 'the-chipsets-names']
+        sensors_chipsets = ["who-cares-about", "the-chipsets-names"]
 
         # pylint: disable=protected-access
         Temperature._run_sensors(self.temperature_mock, sensors_chipsets)
@@ -138,7 +136,7 @@ class TestTemperatureEntry(unittest.TestCase, CustomAssertions):
         # Check that our `run` mock has been called up to the number of passed chipsets.
         self.assertEqual(run_mock.call_count, len(sensors_chipsets))
 
-    @patch('archey.entries.temperature.run')
+    @patch("archey.entries.temperature.run")
     def test_run_sensors_ok_excluded_subfeatures(self, run_mock):
         """Test `sensors` when chipset subfeatures have been excluded"""
         run_mock.side_effect = [
@@ -155,7 +153,7 @@ class TestTemperatureEntry(unittest.TestCase, CustomAssertions):
    }
 }
 """,
-                stderr=None
+                stderr=None,
             )
         ]
 
@@ -165,11 +163,11 @@ class TestTemperatureEntry(unittest.TestCase, CustomAssertions):
         # pylint: enable=protected-access
 
     @patch(
-        'archey.entries.temperature.run',
+        "archey.entries.temperature.run",
         side_effect=[
-            CalledProcessError(1, 'sensors'),  # `sensors` will hard fail.
-            FileNotFoundError()                # `sensors` won't be available.
-        ]
+            CalledProcessError(1, "sensors"),  # `sensors` will hard fail.
+            FileNotFoundError(),  # `sensors` won't be available.
+        ],
     )
     def test_run_sensors_ko_exec(self, _):
         """Test `sensors` (hard) failure handling"""
@@ -181,7 +179,7 @@ class TestTemperatureEntry(unittest.TestCase, CustomAssertions):
         self.assertListEmpty(self.temperature_mock._temps)
         # pylint: enable=protected-access
 
-    @patch('archey.entries.temperature.run')
+    @patch("archey.entries.temperature.run")
     def test_run_sensors_ko_output(self, run_mock):
         """Test `sensors` (soft) failure handling"""
         # JSON decoding from `sensors` will fail...
@@ -197,7 +195,7 @@ class TestTemperatureEntry(unittest.TestCase, CustomAssertions):
         self.assertListEmpty(self.temperature_mock._temps)
         # pylint: enable=protected-access
 
-    @patch('archey.entries.temperature.iglob')
+    @patch("archey.entries.temperature.iglob")
     def test_poll_thermal_zones(self, iglob_mock):
         """Tests sensor files handling"""
 
@@ -205,12 +203,7 @@ class TestTemperatureEntry(unittest.TestCase, CustomAssertions):
         # We'll store there filenames of some temp files mocking those under
         #  `/sys/class/thermal/thermal_zone*/temp`
         tmp_files = []
-        for temperature in (  # Fake temperatures
-                b'50000',
-                b'0',
-                b'40000',
-                b'50000'
-            ):
+        for temperature in (b"50000", b"0", b"40000", b"50000"):  # Fake temperatures
             with tempfile.NamedTemporaryFile(delete=False) as temp_file:
                 temp_file.write(temperature)
                 temp_file.seek(0)
@@ -221,10 +214,7 @@ class TestTemperatureEntry(unittest.TestCase, CustomAssertions):
 
         # pylint: disable=protected-access
         Temperature._poll_thermal_zones(self.temperature_mock)
-        self.assertListEqual(
-            self.temperature_mock._temps,
-            [50.0, 40.0, 50.0]
-        )
+        self.assertListEqual(self.temperature_mock._temps, [50.0, 40.0, 50.0])
         # pylint: enable=protected-access
 
         ## BEGIN POSTLUDE ##
@@ -234,21 +224,21 @@ class TestTemperatureEntry(unittest.TestCase, CustomAssertions):
         ## END POSTLUDE ##
 
     @patch(
-        'archey.entries.temperature.check_output',
+        "archey.entries.temperature.check_output",
         side_effect=[
             # First case (`iStats` nor `OSX CPU Temp` won't be available).
             FileNotFoundError(),
             FileNotFoundError(),
             # Second case (`iStats` OK).
-            '41.125\n',
+            "41.125\n",
             # Third case (`iStats` KO, `OSX CPU Temp` OK).
             FileNotFoundError(),
-            '61.8 °C\n',
+            "61.8 °C\n",
             # Fourth case (`OSX CPU Temp` KO, but with <= 1.1.0 output).
             # See lavoiesl/osx-cpu-temp#22.
             FileNotFoundError(),
-            '0.0°C\n'
-        ]
+            "0.0°C\n",
+        ],
     )
     def test_run_istats_or_osxcputemp(self, _):
         """Test for `iStats` and `OSX CPU Temp` third-party programs outputs"""
@@ -277,16 +267,15 @@ class TestTemperatureEntry(unittest.TestCase, CustomAssertions):
         # pylint: enable=protected-access
 
     @patch(
-        'archey.entries.temperature.os.cpu_count',
-        return_value=4  # Mocks a quad-cores CPU system.
+        "archey.entries.temperature.os.cpu_count", return_value=4  # Mocks a quad-cores CPU system.
     )
     @patch(
-        'archey.entries.temperature.check_output',
+        "archey.entries.temperature.check_output",
         side_effect=[
             # First case (`sysctl` won't be available).
             FileNotFoundError(),
             # Second case (`sysctl` will fail).
-            CalledProcessError(1, 'sysctl'),
+            CalledProcessError(1, "sysctl"),
             # Third case (OK).
             """\
 42C
@@ -300,7 +289,9 @@ class TestTemperatureEntry(unittest.TestCase, CustomAssertions):
 40
 0
 38
-"""])
+""",
+        ],
+    )
     def test_run_sysctl_dev_cpu(self, _, __):
         """Test for `sysctl` output only"""
         # pylint: disable=protected-access
@@ -314,28 +305,22 @@ class TestTemperatureEntry(unittest.TestCase, CustomAssertions):
 
         # Third case.
         Temperature._run_sysctl_dev_cpu(self.temperature_mock)
-        self.assertListEqual(
-            self.temperature_mock._temps,
-            [42.0, 42.0, 45.0, 45.0]
-        )
+        self.assertListEqual(self.temperature_mock._temps, [42.0, 42.0, 45.0, 45.0])
 
         # Reset internal object here.
         self.temperature_mock._temps = []
 
         # Fourth case.
         Temperature._run_sysctl_dev_cpu(self.temperature_mock)
-        self.assertListEqual(
-            self.temperature_mock._temps,
-            [42.0, 40.0, 38.0]
-        )
+        self.assertListEqual(self.temperature_mock._temps, [42.0, 40.0, 38.0])
         # pylint: enable=protected-access
 
     @patch(
-        'archey.entries.temperature.check_output',
+        "archey.entries.temperature.check_output",
         side_effect=[
             FileNotFoundError(),
-            'temp=42.8\'C\n'
-        ]
+            "temp=42.8'C\n",
+        ],
     )
     def test_run_vcgencmd(self, _):
         """Test for `vcgencmd` output only"""
@@ -355,41 +340,32 @@ class TestTemperatureEntry(unittest.TestCase, CustomAssertions):
         # No value --> not detected.
         Temperature.output(self.temperature_mock, output_mock)
         self.assertEqual(
-            output_mock.append.call_args[0][1],
-            DEFAULT_CONFIG['default_strings']['not_detected']
+            output_mock.append.call_args[0][1], DEFAULT_CONFIG["default_strings"]["not_detected"]
         )
 
         output_mock.reset_mock()
 
         # Values --> normal behavior.
-        self.temperature_mock._temps = [  # pylint: disable=protected-access
-            50.0, 40.0, 50.0
-        ]
+        self.temperature_mock._temps = [50.0, 40.0, 50.0]  # pylint: disable=protected-access
         self.temperature_mock.value = {
-            'temperature': 46.7,
-            'max_temperature': 50.0,
-            'char_before_unit': 'o',
-            'unit': 'C'
+            "temperature": 46.7,
+            "max_temperature": 50.0,
+            "char_before_unit": "o",
+            "unit": "C",
         }
         Temperature.output(self.temperature_mock, output_mock)
-        self.assertEqual(
-            output_mock.append.call_args[0][1],
-            '46.7oC (Max. 50.0oC)'
-        )
+        self.assertEqual(output_mock.append.call_args[0][1], "46.7oC (Max. 50.0oC)")
 
         # Only one value --> no maximum.
         self.temperature_mock._temps = [42.8]  # pylint: disable=protected-access
         self.temperature_mock.value = {
-            'temperature': 42.8,
-            'max_temperature': 42.8,
-            'char_before_unit': ' ',
-            'unit': 'C'
+            "temperature": 42.8,
+            "max_temperature": 42.8,
+            "char_before_unit": " ",
+            "unit": "C",
         }
         Temperature.output(self.temperature_mock, output_mock)
-        self.assertEqual(
-            output_mock.append.call_args[0][1],
-            '42.8 C'
-        )
+        self.assertEqual(output_mock.append.call_args[0][1], "42.8 C")
 
     def test_convert_to_fahrenheit(self):
         """Simple tests for the `_convert_to_fahrenheit` static method"""
@@ -398,14 +374,16 @@ class TestTemperatureEntry(unittest.TestCase, CustomAssertions):
             (0.0, 32.0),
             (21.0, 69.8),
             (37.0, 98.6),
-            (100.0, 212.0)
+            (100.0, 212.0),
         )
         for celsius_value, expected_fahrenheit_value in test_conversion_cases:
             self.assertAlmostEqual(
-                Temperature._convert_to_fahrenheit(celsius_value),  # pylint: disable=protected-access
-                expected_fahrenheit_value
+                Temperature._convert_to_fahrenheit(  # pylint: disable=protected-access
+                    celsius_value
+                ),
+                expected_fahrenheit_value,
             )
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
